---
title: 관리자 계정은 몇 개까지 추가할 수 있나요?
category: 자주 묻는 질문 (일반 문의) > 관리자콘솔 > 관리자콘솔 문의
seo:
  title: 관리자 계정은 몇 개까지 추가할 수 있나요?
  description: >-
    포트원 관리자콘솔 계정의 권한별 생성가능한 경로 및 갯수 안내입니다. 계정추가 경로, 권한별 설정가능 갯수, 권한별 이용 가능한 기능
    모두 확인해보세요.
  keywords:
    - 관리자콘솔
tags:
  - 관리자콘솔
pgCompanies:
  - 공통
searchTags:
  - 권한추가
  - 관리자권한추가
  - 관리자권한
  - 관리자계정
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="" title="포트원 관리자콘솔의 계정의 권한별 생성가능한 경로 및 갯수를 안내드립니다." />

#### **계정추가 경로**

[관리자콘솔 상점·계정관리 ↗](https://admin.portone.io/merchant) > 관리자 계정관리 > 관리자계정 추가



#### **권한별 설정가능 갯수**

- admin : 1개
- dev : 10개
- manager / read only : 갯수 제한 없음

#### **권한별 이용 가능한 기능**

- admin : 전체 권한
- dev : 연동, 내역 조회
- manager : 내역 조회/수정, 리포트, 계정 관리
- read only : 내역 조회/ 리포트
